@@ -13,6 +13,12 @@ function addSubscription() {
   $("ul#menu").append(loader);
   $.post('/api/add', {url: url}, function(data) {
     if (data.success == true) {
+      /////////////////////////////////////
+      // Go login page if not connected ///
+      if ($(data).find('.form-signin').length > 0) {
+        window.location = "/login";
+      }
+      /////////////////////////////////////
       $(loader).hide();
       $(loader).html('<a onClick="viewSubscription(&quot;' + data.feed_id + '&quot;)" href="/#' + data.feed_id + '">' + data.title + ' <span id="unread-counter" class="badge badge-inverse">' + data.counter  + '</span></a>').fadeIn();
       $(loader).attr('id', data.feed_id);
@@ -47,45 +53,72 @@ function handleOPMLImport(evt) {
     // Great success! All the File APIs are supported.
   } else {
     alert('The File APIs are not fully supported in this browser.');
+    return false;
   }
 
   // Retrieve file from form
+  importer = true;
   var file = document.getElementById('OPMLFile').files[0]
-  console.log(file);
-  if (!file) {
-    return false
-  }
+  if (!file) { return false }
   var reader = new FileReader();
 
   reader.onload = (function(OPMLFile) {
     return function(e) {
       $.post('/api/import/opml', { file: e.target.result }, function(data) {
+        /////////////////////////////////////
+        // Go login page if not connected ///
+        if ($(data).find('.form-signin').length > 0) {
+          window.location = "/login";
+        }
+        /////////////////////////////////////
         if (data.success == true) {
-          importer = true;
+          importer = false;
           $('#OPMLSubmit').html('Importing, reload page later...');
           $('#OPMLSubmit').addClass('disabled');
         }
       });
     }
   })(file);
-
   reader.readAsText(file);
 }
 
 function viewSettings() {
   $.get('/settings', function(body) {
+    /////////////////////////////////////
+    // Go login page if not connected ///
+    if ($(body).find('.form-signin').length > 0) {
+      window.location = "/login";
+    }
+    /////////////////////////////////////
     var content = $(body).find('#content');
+    var sidebar = $(body).find('#menu')
     $('#content').html(content.html());
-    eval($(body).find('script').html());
-    window.history.pushState(document.title,document.title,"/settings");
+    $('#menu').html(sidebar.html());
+    if (importer) {
+      $('#OPMLSubmit').html('Last import not finished...');
+      $('#OPMLSubmit').addClass('disabled');
+      return false;
+    }
+    if ($('#OPMLSubmit').length > 0) {
+      document.getElementById('OPMLSubmit').addEventListener('click', handleOPMLImport, false);
+    }
+    initAddSubscription();
   });
 }
 
 function viewHome() {
-  $.get('/', function(content) {
-    var content = $(content).find('#content');
+  $.get('/', function(body) {
+    /////////////////////////////////////
+    // Go login page if not connected ///
+    if ($(body).find('.form-signin').length > 0) {
+      window.location = "/login";
+    }
+    /////////////////////////////////////
+    var content = $(body).find('#content');
+    var sidebar = $(body).find('#menu')
     $('#content').html(content.html());
-    window.history.pushState(document.title,document.title,"/");
+    $('#menu').html(sidebar.html());
+    initAddSubscription();
   });
 }
 
@@ -94,16 +127,26 @@ function delSubscription(feedId) {
     url: '/api/remove/' + feedId,
     type: 'DELETE',
     success: function(result) {
-      $('#feeds ul li#' + feedId).remove();
-      $('ul#menu li#' + feedId).remove();
-      if ($('#feeds ul li').length < 1) {
-        $('#feeds.tab-pane #empty-feed-list').show();
-      }
-      console.log($('ul#menu li').length);
-      if ($('ul#menu li').length < 6) {
-        $('ul#menu li#listSubscriptions.nav-header').hide();
-        $('ul#menu li#empty-feed-list').show();
+      /////////////////////////////////////
+      // Go login page if not connected ///
+      if ($(result).find('.form-signin').length > 0) {
+        window.location = "/login";
       }
+      /////////////////////////////////////
+      $('#feeds ul li#' + feedId).fadeOut(300, function() {
+        $(this).remove();
+        if ($('#feeds ul li').length < 1) {
+          $('#feeds.tab-pane #empty-feed-list').fadeIn(200);
+        }
+      });
+      $('ul#menu li#' + feedId).fadeOut(300, function() {
+        $(this).remove();
+        if ($('ul#menu li').length < 6) {
+          $('ul#menu li#listSubscriptions.nav-header').fadeOut(200);
+          $('ul#menu li#empty-feed-list').fadeIn(200);
+        }
+      });
+      //$('ul#menu li#' + feedId).remove();  
     }
   });
 }
@@ -114,6 +157,12 @@ function viewSubscription(feedId) {
       requests.shift();
   });
   var request = $.getJSON('/api/get/' + feedId, function(data) {
+    /////////////////////////////////////
+    // Go login page if not connected ///
+    if ($(data).find('.form-signin').length > 0) {
+      window.location = "/login";
+    }
+    /////////////////////////////////////
     $('#content').html('<div class="accordion" id="accordion2">');
     $.each(data.content, function(i,item){
       var content = '<div class="accordion-group">                                                                                            \
@@ -144,6 +193,12 @@ function refreshSubscriptions() {
       refresher.shift();
   });
   var refresh = $.getJSON('/api/refresh', function(data) {
+    /////////////////////////////////////
+    // Go login page if not connected ///
+    if ($(data).find('.form-signin').length > 0) {
+      window.location = "/login";
+    }
+    /////////////////////////////////////
     $.each(data.content, function(i,feed) {
       var feed_title = feed[0];
       var feed_id = feed[1];
@@ -159,6 +214,13 @@ function readEntry(entryId) {
     return true;
   }
   $.getJSON('/api/read/' + entryId, function(data) {
+    /////////////////////////////////////
+    // Go login page if not connected ///
+    if ($(data).find('.form-signin').length > 0) {
+
+      window.location = "/login";
+    }
+    /////////////////////////////////////
     var published = data.content.last_update['year'] + '-' + data.content.last_update['month'] +
                     '-' + data.content.last_update['day'];
 
@@ -174,22 +236,18 @@ function readEntry(entryId) {
     $('#content #' + entryId).html(story_raw)
     if (data.content.last_read_state == false) {
       var feed_id = data.content.feed_id;
-      var counter = $("#menu a[href=#" + feed_id + "] span.badge").html() - 1;
+      var counter = $("#menu li#" + feed_id + " #unread-counter").html() - 1;
       if (counter == 0) {
-        $("#menu a[href=#" + feed_id + "] span.badge").remove();
+        $("#menu li#" + feed_id + " #unread-counter").remove();
       } else {
-        $("#menu a[href=#" + feed_id + "] span.badge").html(counter);
+        $("#menu li#" + feed_id + " #unread-counter").html(counter);
       }
     }
   });
   $('a[href=#' + entryId + ']').css('font-weight', 'normal').data('loaded', true);
 }
 
-$(document).ready(function(){
-  // Globals
-  requests = new Array();
-  refresher = new Array();
-  importer = false;
+function initAddSubscription(){
   // Add subscription pop up
   var add_subscription = $('#template-add-subscription').clone();
   add_subscription.removeAttr('id');
@@ -197,4 +255,12 @@ $(document).ready(function(){
   var add_subscription_raw = add_subscription.wrap('<form/>').parent().html();
   add_subscription.unwrap();
   $('#add').popover({title:"<center>New subscription</center>",html:true,content:add_subscription_raw,placement:"bottom"});
+}
+
+$(document).ready(function(){
+  // Globals
+  requests = new Array();
+  refresher = new Array();
+  importer = false;
+  initAddSubscription();
 });
\ No newline at end of file
